@@ -31,13 +31,7 @@
  */
 package org.lwjgl;
 
-import java.nio.Buffer;
-import java.nio.ByteBuffer;
-import java.nio.DoubleBuffer;
-import java.nio.FloatBuffer;
-import java.nio.IntBuffer;
-import java.nio.ShortBuffer;
-import java.nio.LongBuffer;
+import java.nio.*;
 
 /**
  * <p>A class to check buffer boundaries in general. If there is unsufficient space
@@ -48,8 +42,8 @@ import java.nio.LongBuffer;
  * </p>
  * @author cix_foo <cix_foo@users.sourceforge.net>
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3334 $
- * $Id: BufferChecks.java 3334 2010-04-22 23:21:48Z spasi $
+ * @version $Revision: 3419 $
+ * $Id: BufferChecks.java 3419 2010-09-30 17:21:50Z spasi $
  */
 public class BufferChecks {
 	/** Static methods only! */
@@ -87,9 +81,23 @@ public class BufferChecks {
 		}
 	}
 
-	/** Helper methods to ensure an IntBuffer is null-terminated */
+	/** Helper method to ensure an IntBuffer is null-terminated */
 	public static void checkNullTerminated(IntBuffer buf) {
-		if ( buf.get(buf.limit() - 1) != 0 ) {
+		if ( LWJGLUtil.CHECKS && buf.get(buf.limit() - 1) != 0 ) {
+			throw new IllegalArgumentException("Missing null termination");
+		}
+	}
+
+	/** Helper method to ensure a LongBuffer is null-terminated */
+	public static void checkNullTerminated(LongBuffer buf) {
+		if ( LWJGLUtil.CHECKS && buf.get(buf.limit() - 1) != 0 ) {
+			throw new IllegalArgumentException("Missing null termination");
+		}
+	}
+
+	/** Helper method to ensure a PointerBuffer is null-terminated */
+	public static void checkNullTerminated(PointerBuffer buf) {
+		if ( LWJGLUtil.CHECKS && buf.get(buf.limit() - 1) != 0 ) {
 			throw new IllegalArgumentException("Missing null termination");
 		}
 	}
@@ -138,6 +146,15 @@ public class BufferChecks {
 		}
 	}
 
+	public static void checkDirect(PointerBuffer buf) {
+		// NO-OP, PointerBuffer is always direct.
+	}
+
+	public static void checkArray(Object[] array) {
+		if ( LWJGLUtil.CHECKS && (array == null || array.length == 0) )
+			throw new IllegalArgumentException("Invalid array");
+	}
+
 	/**
 	 * This is a separate call to help inline checkBufferSize.
 	 */
@@ -145,6 +162,18 @@ public class BufferChecks {
 		throw new IllegalArgumentException("Number of remaining buffer elements is " + buf.remaining() + ", must be at least " + size);
 	}
 
+	private static void throwBufferSizeException(PointerBuffer buf, int size) {
+		throw new IllegalArgumentException("Number of remaining pointer buffer elements is " + buf.remaining() + ", must be at least " + size);
+	}
+
+	private static void throwArraySizeException(Object[] array, int size) {
+		throw new IllegalArgumentException("Number of array elements is " + array.length + ", must be at least " + size);
+	}
+
+	private static void throwArraySizeException(long[] array, int size) {
+		throw new IllegalArgumentException("Number of array elements is " + array.length + ", must be at least " + size);
+	}
+
 	/**
 	 * Helper method to ensure a buffer is big enough to receive data from a
 	 * glGet* operation.
@@ -161,6 +190,41 @@ public class BufferChecks {
 		}
 	}
 
+	/**
+	 * Detects the buffer type and performs the corresponding check
+	 * and also returns the buffer position in bytes.
+	 *
+	 * @param buffer the buffer to check
+	 * @param size   the size to check
+	 *
+	 * @return the buffer position in bytes
+	 */
+	public static int checkBuffer(final Buffer buffer, final int size) {
+		final int posShift;
+		if ( buffer instanceof ByteBuffer ) {
+			BufferChecks.checkBuffer((ByteBuffer)buffer, size);
+			posShift = 0;
+		} else if ( buffer instanceof ShortBuffer ) {
+			BufferChecks.checkBuffer((ShortBuffer)buffer, size);
+			posShift = 1;
+		} else if ( buffer instanceof IntBuffer ) {
+			BufferChecks.checkBuffer((IntBuffer)buffer, size);
+			posShift = 2;
+		} else if ( buffer instanceof LongBuffer ) {
+			BufferChecks.checkBuffer((LongBuffer)buffer, size);
+			posShift = 4;
+		} else if ( buffer instanceof FloatBuffer ) {
+			BufferChecks.checkBuffer((FloatBuffer)buffer, size);
+			posShift = 2;
+		} else if ( buffer instanceof DoubleBuffer ) {
+			BufferChecks.checkBuffer((DoubleBuffer)buffer, size);
+			posShift = 4;
+		} else
+			throw new IllegalArgumentException("Unsupported Buffer type specified: " + buffer.getClass());
+
+		return buffer.position() << posShift;
+	}
+
 	public static void checkBuffer(ByteBuffer buf, int size) {
 		if ( LWJGLUtil.CHECKS ) {
 			checkBufferSize(buf, size);
@@ -202,4 +266,21 @@ public class BufferChecks {
 			checkDirect(buf);
 		}
 	}
-}
+
+	public static void checkBuffer(PointerBuffer buf, int size) {
+		if ( LWJGLUtil.CHECKS && buf.remaining() < size ) {
+			throwBufferSizeException(buf, size);
+		}
+	}
+
+	public static void checkArray(Object[] array, int size) {
+		if ( LWJGLUtil.CHECKS && array.length < size )
+			throwArraySizeException(array, size);
+	}
+
+	public static void checkArray(long[] array, int size) {
+		if ( LWJGLUtil.CHECKS && array.length < size )
+			throwArraySizeException(array, size);
+	}
+
+}
\ No newline at end of file
