@@ -32,16 +32,15 @@
 package org.lwjgl;
 
 import java.io.File;
+import java.lang.reflect.Field;
 import java.lang.reflect.Method;
+import java.lang.reflect.Modifier;
 import java.nio.ByteBuffer;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.security.PrivilegedActionException;
 import java.security.PrivilegedExceptionAction;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.StringTokenizer;
-
+import java.util.*;
 
 /**
  * <p>
@@ -49,8 +48,8 @@ import java.util.StringTokenizer;
  * </p>
  *
  * @author Brian Matzon <brian@matzon.dk>
- * @version $Revision: 3334 $
- * $Id: LWJGLUtil.java 3334 2010-04-22 23:21:48Z spasi $
+ * @version $Revision: 3475 $
+ * $Id: LWJGLUtil.java 3475 2011-01-23 07:48:50Z matzon $
  */
 public class LWJGLUtil {
 	public static final int PLATFORM_LINUX 				= 1;
@@ -59,9 +58,9 @@ public class LWJGLUtil {
 	public static final String PLATFORM_LINUX_NAME 		= "linux";
 	public static final String PLATFORM_MACOSX_NAME 	= "macosx";
 	public static final String PLATFORM_WINDOWS_NAME	= "windows";
-	
+
 	/** LWJGL Logo - 16 by 16 pixels */
-	public static final ByteBuffer	LWJGLIcon16x16		= BufferUtils.createByteBuffer(16 * 16 * 4).put(new byte[] { 
+	public static final ByteBuffer	LWJGLIcon16x16		= BufferUtils.createByteBuffer(16 * 16 * 4).put(new byte[] {
 			-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
 			-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -2, -1, -1, -1, -62, -41, -24, -1, 116, -92, -53, -1, 80, -117,
 			-67, -1, 84, -114, -65, -1, -122, -81, -46, -1, -25, -17, -10, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
@@ -106,7 +105,7 @@ public class LWJGLUtil {
 	});
 
 	/** LWJGL Logo - 32 by 32 pixels */
-	public static final ByteBuffer	LWJGLIcon32x32		= BufferUtils.createByteBuffer(32 * 32 * 4).put(new byte[] { 
+	public static final ByteBuffer	LWJGLIcon32x32		= BufferUtils.createByteBuffer(32 * 32 * 4).put(new byte[] {
 			-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
 			-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
 			-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -6, -4, -3, -1, -53, -35,
@@ -269,11 +268,23 @@ public class LWJGLUtil {
 
 	public static final boolean CHECKS = !getPrivilegedBoolean("org.lwjgl.util.NoChecks");
 
+	private static final int PLATFORM;
+
 	static {
 		LWJGLIcon16x16.flip();
 		LWJGLIcon32x32.flip();
+
+		final String osName = getPrivilegedProperty("os.name");
+		if ( osName.startsWith("Windows") )
+			PLATFORM = PLATFORM_WINDOWS;
+		else if ( osName.startsWith("Linux") || osName.startsWith("FreeBSD") || osName.startsWith("SunOS") )
+			PLATFORM = PLATFORM_LINUX;
+		else if ( osName.startsWith("Mac OS X") || osName.startsWith("Darwin") )
+			PLATFORM = PLATFORM_MACOSX;
+		else
+			throw new LinkageError("Unknown platform: " + osName);
 	}
-	
+
 	/**
 	 * @see #PLATFORM_WINDOWS
 	 * @see #PLATFORM_LINUX
@@ -281,19 +292,9 @@ public class LWJGLUtil {
 	 * @return the current platform type
 	 */
 	public static int getPlatform() {
-		String osName = getPrivilegedProperty("os.name");
-
-		if (osName.startsWith("Windows")) {
-			return PLATFORM_WINDOWS;
-		} else if (osName.startsWith("Linux") || osName.startsWith("FreeBSD") || osName.startsWith("SunOS")) {
-			return PLATFORM_LINUX;
-		} else if (osName.startsWith("Mac OS X")) {
-			return PLATFORM_MACOSX;
-		} else {
-			throw new LinkageError("Unknown platform: " + osName);
-		}
+		return PLATFORM;
 	}
-	
+
 
 	/**
 	 * @see #PLATFORM_WINDOWS_NAME
@@ -312,7 +313,7 @@ public class LWJGLUtil {
 			default:
 				return "unknown";
 		}
-	}	
+	}
 
 	/**
 	 * Locates the paths required by a library.
@@ -336,7 +337,7 @@ public class LWJGLUtil {
 	 */
 	public static String[] getLibraryPaths(String libname, String[] platform_lib_names, ClassLoader classloader) {
 		// need to pass path of possible locations of library to native side
-		List possible_paths = new ArrayList();
+		List<String> possible_paths = new ArrayList<String>();
 
 		String classloader_path = getPathFromClassLoader(libname, classloader);
 		if (classloader_path != null) {
@@ -344,26 +345,25 @@ public class LWJGLUtil {
 			possible_paths.add(classloader_path);
 		}
 
-		for (int i = 0; i < platform_lib_names.length; i++) {
-			String platform_lib_name = platform_lib_names[i];
+		for ( String platform_lib_name : platform_lib_names ) {
 			String lwjgl_classloader_path = getPathFromClassLoader("lwjgl", classloader);
-			if (lwjgl_classloader_path != null) {
+			if ( lwjgl_classloader_path != null ) {
 				log("getPathFromClassLoader: Path found: " + lwjgl_classloader_path);
 				possible_paths.add(lwjgl_classloader_path.substring(0, lwjgl_classloader_path.lastIndexOf(File.separator))
-						+ File.separator + platform_lib_name);
+				                   + File.separator + platform_lib_name);
 			}
 
 			// add Installer path
 			String alternative_path = getPrivilegedProperty("org.lwjgl.librarypath");
-			if (alternative_path != null) {
+			if ( alternative_path != null ) {
 				possible_paths.add(alternative_path + File.separator + platform_lib_name);
-			}		
+			}
 
 			// Add all possible paths from java.library.path
 			String java_library_path = getPrivilegedProperty("java.library.path");
 
 			StringTokenizer st = new StringTokenizer(java_library_path, File.pathSeparator);
-			while (st.hasMoreTokens()) {
+			while ( st.hasMoreTokens() ) {
 				String path = st.nextToken();
 				possible_paths.add(path + File.separator + platform_lib_name);
 			}
@@ -377,15 +377,13 @@ public class LWJGLUtil {
 		}
 
 		//create needed string array
-		String[] paths = new String[possible_paths.size()];
-		possible_paths.toArray(paths);
-		return paths;
+		return possible_paths.toArray(new String[possible_paths.size()]);
 	}
 
 	static void execPrivileged(final String[] cmd_array) throws Exception {
 		try {
-			Process process = (Process)AccessController.doPrivileged(new PrivilegedExceptionAction() {
-				public Object run() throws Exception {
+			Process process = AccessController.doPrivileged(new PrivilegedExceptionAction<Process>() {
+				public Process run() throws Exception {
 					return Runtime.getRuntime().exec(cmd_array);
 				}
 			});
@@ -399,8 +397,8 @@ public class LWJGLUtil {
 	}
 
 	private static String getPrivilegedProperty(final String property_name) {
-		return (String)AccessController.doPrivileged(new PrivilegedAction() {
-			public Object run() {
+		return AccessController.doPrivileged(new PrivilegedAction<String>() {
+			public String run() {
 				return System.getProperty(property_name);
 			}
 		});
@@ -420,16 +418,15 @@ public class LWJGLUtil {
 	private static String getPathFromClassLoader(final String libname, final ClassLoader classloader) {
 		try {
 			log("getPathFromClassLoader: searching for: " + libname);
-			Class c = classloader.getClass();
+			Class<?> c = classloader.getClass();
 			while (c != null) {
-				final Class clazz = c;
+				final Class<?> clazz = c;
 				try {
-					return (String)AccessController.doPrivileged(new PrivilegedExceptionAction() {
-						public Object run() throws Exception {
-							Method findLibrary = clazz.getDeclaredMethod("findLibrary", new Class[]{String.class});
+					return AccessController.doPrivileged(new PrivilegedExceptionAction<String>() {
+						public String run() throws Exception {
+							Method findLibrary = clazz.getDeclaredMethod("findLibrary", String.class);
 							findLibrary.setAccessible(true);
-							Object[] arguments = new Object[] {libname};
-							String path = (String)findLibrary.invoke(classloader, arguments);
+							String path = (String)findLibrary.invoke(classloader, libname);
 							return path;
 						}
 					});
@@ -448,17 +445,17 @@ public class LWJGLUtil {
 	 * Gets a boolean property as a privileged action.
 	 */
 	private static boolean getPrivilegedBoolean(final String property_name) {
-		Boolean value = (Boolean)AccessController.doPrivileged(new PrivilegedAction() {
-			public Object run() {	
-				return new Boolean(Boolean.getBoolean(property_name));
+		Boolean value = AccessController.doPrivileged(new PrivilegedAction<Boolean>() {
+			public Boolean run() {
+				return Boolean.getBoolean(property_name);
 			}
 		});
-		return value.booleanValue();
-	}	
-	
+		return value;
+	}
+
 	/**
 	 * Prints the given message to System.err if DEBUG is true.
-	 * 
+	 *
 	 * @param msg Message to print
 	 */
 	public static void log(String msg) {
@@ -466,7 +463,7 @@ public class LWJGLUtil {
 			System.err.println(msg);
 		}
 	}
-	
+
 	/**
 	 * Method to determine if the current system is running a version of
 	 * Mac OS X better than the given version. This is only useful for Mac OS X
@@ -489,5 +486,93 @@ public class LWJGLUtil {
 		}
 		return major > major_required || (major == major_required && minor >= minor_required);
 	}
-	
-}
+
+	/**
+	 * Returns a map of public static final integer fields in the specified classes, to their String representations.
+	 * An optional filter can be specified to only include specific fields. The target map may be null, in which
+	 * case a new map is allocated and returned.
+	 * <p>
+	 * This method is useful when debugging to quickly identify values returned from the AL/GL/CL APIs.
+	 *
+	 * @param filter       the filter to use (optional)
+	 * @param target       the target map (optional)
+	 * @param tokenClasses an array of classes to get tokens from
+	 *
+	 * @return the token map
+	 */
+
+	public static Map<Integer, String> getClassTokens(final TokenFilter filter, final Map<Integer, String> target, final Class ... tokenClasses) {
+		return getClassTokens(filter, target, Arrays.asList(tokenClasses));
+	}
+
+	/**
+	 * Returns a map of public static final integer fields in the specified classes, to their String representations.
+	 * An optional filter can be specified to only include specific fields. The target map may be null, in which
+	 * case a new map is allocated and returned.
+	 * <p>
+	 * This method is useful when debugging to quickly identify values returned from the AL/GL/CL APIs.
+	 *
+	 * @param filter       the filter to use (optional)
+	 * @param target       the target map (optional)
+	 * @param tokenClasses the classes to get tokens from
+	 *
+	 * @return the token map
+	 */
+	public static Map<Integer, String> getClassTokens(final TokenFilter filter, Map<Integer, String> target, final Iterable<Class> tokenClasses) {
+		if ( target == null )
+			target = new HashMap<Integer, String>();
+
+		final int TOKEN_MODIFIERS = Modifier.PUBLIC | Modifier.STATIC | Modifier.FINAL;
+
+		for ( final Class tokenClass : tokenClasses ) {
+			for ( final Field field : tokenClass.getDeclaredFields() ) {
+				// Get only <public static final int> fields.
+				if ( (field.getModifiers() & TOKEN_MODIFIERS) == TOKEN_MODIFIERS && field.getType() == int.class ) {
+					try {
+						final int value = field.getInt(null);
+						if ( filter != null && !filter.accept(field, value) )
+							continue;
+
+						if ( target.containsKey(value) ) // Print colliding tokens in their hex representation.
+							target.put(value, toHexString(value));
+						else
+							target.put(value, field.getName());
+					} catch (IllegalAccessException e) {
+						// Ignore
+					}
+				}
+			}
+		}
+
+		return target;
+	}
+
+	/**
+	 * Returns a string representation of the integer argument as an
+	 * unsigned integer in base&nbsp;16. The string will be uppercase
+	 * and will have a leading '0x'.
+	 *
+	 * @param value the integer value
+	 *
+	 * @return the hex string representation
+	 */
+	public static String toHexString(final int value) {
+		return "0x" + Integer.toHexString(value).toUpperCase();
+	}
+
+	/** Simple interface for Field filtering. */
+	public interface TokenFilter {
+
+		/**
+		 * Should return true if the specified Field passes the filter.
+		 *
+		 * @param field the Field to test
+		 * @param value the integer value of the field
+		 *
+		 * @result true if the Field is accepted
+		 */
+		boolean accept(Field field, int value);
+
+	}
+
+}
\ No newline at end of file
