@@ -46,27 +46,28 @@ import org.lwjgl.input.Mouse;
  * System class (named Sys so as not to conflict with java.lang.System)
  * </p>
  * @author cix_foo <cix_foo@users.sourceforge.net>
- * @version $Revision: 3353 $
- * $Id: Sys.java 3353 2010-05-24 22:39:06Z matzon $
+ * @version $Revision: 3488 $
+ * $Id: Sys.java 3488 2011-02-09 21:09:33Z matzon $
  */
 public final class Sys {
 	/** The native library name */
 	private static final String JNI_LIBRARY_NAME = "lwjgl";
 
 	/** Current version of library */
-	private static final String VERSION = "2.5";
+	private static final String VERSION = "2.7.1";
+
+	private static final String POSTFIX64BIT = "64";
 
 	/** The implementation instance to delegate platform specific behavior to */
-	private final static SysImplementation implementation;
+	private static final SysImplementation implementation;
+	private static final boolean is64Bit;
 
-	private final static String POSTFIX64BIT = "64";
-  
 	private static void doLoadLibrary(final String lib_name) {
-		AccessController.doPrivileged(new PrivilegedAction() {
+		AccessController.doPrivileged(new PrivilegedAction<Object>() {
 			public Object run() {
 				String library_path = System.getProperty("org.lwjgl.librarypath");
 				if (library_path != null) {
-					System.load(library_path + File.separator + 
+					System.load(library_path + File.separator +
 						System.mapLibraryName(lib_name));
 				} else {
 					System.loadLibrary(lib_name);
@@ -91,17 +92,18 @@ public final class Sys {
 			// Throw original error
 			throw e;
 		}
-	}	
+	}
 
 	static {
 		implementation = createImplementation();
 		loadLibrary(JNI_LIBRARY_NAME);
-		
+		is64Bit = implementation.getPointerSize() == 8;
+
 		int native_jni_version = implementation.getJNIVersion();
 		int required_version = implementation.getRequiredJNIVersion();
 		if (native_jni_version != required_version)
 			throw new LinkageError("Version mismatch: jar version is '" + required_version +
-                             "', native libary version is '" + native_jni_version + "'");
+                             "', native library version is '" + native_jni_version + "'");
 		implementation.setDebug(LWJGLUtil.DEBUG);
 	}
 
@@ -130,13 +132,18 @@ public final class Sys {
 	public static String getVersion() {
 		return VERSION;
 	}
-	
+
 	/**
 	 * Initialization. This is just a dummy method to trigger the static constructor.
 	 */
 	public static void initialize() {
 	}
 
+	/** Returns true if a 64bit implementation was loaded. */
+	public static boolean is64Bit() {
+		return is64Bit;
+	}
+
 	/**
 	 * Obtains the number of ticks that the hires timer does in a second. This method is fast;
 	 * it should be called as frequently as possible, as it recalibrates the timer.
@@ -208,22 +215,22 @@ public final class Sys {
 		// Attempt to use Webstart if we have it available
 		try {
 			// Lookup the javax.jnlp.BasicService object
-			final Class serviceManagerClass = Class.forName("javax.jnlp.ServiceManager");
-			Method lookupMethod = (Method)AccessController.doPrivileged(new PrivilegedExceptionAction() {
-				public Object run() throws Exception {
-					return serviceManagerClass.getMethod("lookup", new Class[] {String.class});
+			final Class<?> serviceManagerClass = Class.forName("javax.jnlp.ServiceManager");
+			Method lookupMethod = AccessController.doPrivileged(new PrivilegedExceptionAction<Method>() {
+				public Method run() throws Exception {
+					return serviceManagerClass.getMethod("lookup", String.class);
 				}
 			});
 			Object basicService = lookupMethod.invoke(serviceManagerClass, new Object[] {"javax.jnlp.BasicService"});
-			final Class basicServiceClass = Class.forName("javax.jnlp.BasicService");
-			Method showDocumentMethod = (Method)AccessController.doPrivileged(new PrivilegedExceptionAction() {
-				public Object run() throws Exception {
-					return basicServiceClass.getMethod("showDocument", new Class[] {URL.class});
+			final Class<?> basicServiceClass = Class.forName("javax.jnlp.BasicService");
+			Method showDocumentMethod = AccessController.doPrivileged(new PrivilegedExceptionAction<Method>() {
+				public Method run() throws Exception {
+					return basicServiceClass.getMethod("showDocument", URL.class);
 				}
 			});
 			try {
-				Boolean ret = (Boolean) showDocumentMethod.invoke(basicService, new Object[] {new URL(url)});
-				return ret.booleanValue();
+				Boolean ret = (Boolean)showDocumentMethod.invoke(basicService, new URL(url));
+				return ret;
 			} catch (MalformedURLException e) {
 				e.printStackTrace(System.err);
 				return false;
