@@ -1,31 +1,31 @@
-/* 
+/*
  * Copyright (c) 2002-2008 LWJGL Project
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are 
+ * modification, are permitted provided that the following conditions are
  * met:
- * 
- * * Redistributions of source code must retain the above copyright 
+ *
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
  *
  * * Redistributions in binary form must reproduce the above copyright
  *   notice, this list of conditions and the following disclaimer in the
  *   documentation and/or other materials provided with the distribution.
  *
- * * Neither the name of 'LWJGL' nor the names of 
- *   its contributors may be used to endorse or promote products derived 
+ * * Neither the name of 'LWJGL' nor the names of
+ *   its contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
  * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
- * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
- * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
@@ -39,7 +39,7 @@ import org.lwjgl.BufferChecks;
 import org.lwjgl.LWJGLException;
 
 /**
- * 
+ *
  * <p>
  * ALC introduces the notion of a Device. A Device can be, depending on the
  * implementation, a hardware device, or a daemon/OS service/actual server. This
@@ -49,19 +49,19 @@ import org.lwjgl.LWJGLException;
  * implementation, which has to map the available backends to unique device
  * specifiers (represented as strings).
  * </p>
- * 
+ *
  * @author Brian Matzon <brian@matzon.dk>
  * @version $Revision: 2286 $
  * $Id: ALC.java 2286 2006-03-23 19:32:21 +0000 (to, 23 mar 2006) matzon $
  */
 public final class ALC10 {
-	
+
 	/** List of active contexts */
-	static HashMap contexts = new HashMap();
-	
+	static final HashMap<Long, ALCcontext> contexts = new HashMap<Long, ALCcontext>();
+
 	/** List of active devices */
-	static HashMap devices = new HashMap();	
-	
+	static final HashMap<Long, ALCdevice> devices = new HashMap<Long, ALCdevice>();
+
 	/** Bad value */
 	public static final int ALC_INVALID = 0;
 
@@ -80,7 +80,7 @@ public final class ALC10 {
 	/** Minor version query. */
 	public static final int ALC_MINOR_VERSION = 0x1001;
 
-	/** 
+	/**
 	 * The size required for the zero-terminated attributes list, for the current context.
 	 **/
 	public static final int ALC_ATTRIBUTES_SIZE = 0x1002;
@@ -116,7 +116,7 @@ public final class ALC10 {
 	public static final int ALC_INVALID_CONTEXT = 0xA002;
 
 	/**
-	 * A function was called at inappropriate time, or in an inappropriate way, 
+	 * A function was called at inappropriate time, or in an inappropriate way,
 	 * causing an illegal state. This can be an incompatible ALenum, object ID,
 	 * and/or function.
 	 */
@@ -129,24 +129,24 @@ public final class ALC10 {
 	public static final int ALC_INVALID_VALUE = 0xA004;
 
 	/**
-	 * A function could not be completed, because there is not enough 
+	 * A function could not be completed, because there is not enough
 	 * memory available.
 	 */
 	public static final int ALC_OUT_OF_MEMORY = 0xA005;
-	
+
 	static native void initNativeStubs() throws LWJGLException;
-	
+
 	/**
 	 * The application can obtain certain strings from ALC.
-	 * 
+	 *
 	 * <code>ALC_DEFAULT_DEVICE_SPECIFIER</code> - The specifer string for the default device
-	 * <code>ALC_DEVICE_SPECIFIER</code> - The specifer string for the device 
+	 * <code>ALC_DEVICE_SPECIFIER</code> - The specifer string for the device
 	 * <code>ALC_EXTENSIONS</code> - The extensions string for diagnostics and printing.
 	 *
 	 * In addition, printable error message strings are provided for all valid error tokens,
 	 * including <code>ALC_NO_ERROR</code>,<code>ALC_INVALID_DEVICE</code>, <code>ALC_INVALID_CONTEXT</code>,
 	 * <code>ALC_INVALID_ENUM</code>, <code>ALC_INVALID_VALUE</code>.
-	 * 
+	 *
 	 * @param pname Property to get
 	 * @return String property from device
 	 */
@@ -156,7 +156,7 @@ public final class ALC10 {
 		Util.checkALCError(device);
 		return result;
 	}
-	native static String nalcGetString(long device, int pname);
+	static native String nalcGetString(long device, int pname);
 
 	/**
 	 * The application can query ALC for information using an integer query function.
@@ -164,11 +164,11 @@ public final class ALC10 {
 	* device will generate an <code>ALC_INVALID_DEVICE</code> error. The application has to
 	* specify the size of the destination buffer provided. A <code>null</code> destination or a zero
 	* size parameter will cause ALC to ignore the query.
-	* 
+	*
 	* <code>ALC_MAJOR_VERSION</code> - Major version query.
 	* <code>ALC_MINOR_VERSION</code> - Minor version query.
-	* <code>ALC_ATTRIBUTES_SIZE</code> - The size required for the zero-terminated attributes list, 
-	* for the current context. <code>null</code> is an invalid device. <code>null</code> (no current context 
+	* <code>ALC_ATTRIBUTES_SIZE</code> - The size required for the zero-terminated attributes list,
+	* for the current context. <code>null</code> is an invalid device. <code>null</code> (no current context
 	* for the specified device) is legal.
 	* <code>ALC_ALL_ATTRIBUTES</code> - Expects a destination of <code>ALC_CURRENT_ATTRIBUTES_SIZE</code>,
 	* and provides the attribute list for the current context of the specified device.
@@ -183,7 +183,7 @@ public final class ALC10 {
 		nalcGetIntegerv(getDevice(device), pname, integerdata.remaining(), integerdata, integerdata.position());
 		Util.checkALCError(device);
 	}
-	native static void nalcGetIntegerv(long device, int pname, int size, Buffer integerdata, int offset);
+	static native void nalcGetIntegerv(long device, int pname, int size, Buffer integerdata, int offset);
 
 	/**
 	 * The <code>alcOpenDevice</code> function allows the application (i.e. the client program) to
@@ -202,18 +202,18 @@ public final class ALC10 {
 		if(device_address != 0) {
 			ALCdevice device = new ALCdevice(device_address);
 			synchronized (ALC10.devices) {
-				devices.put(new Long(device_address), device);
+				devices.put(device_address, device);
 			}
 			return device;
 		}
 		return null;
 	}
-	native static long nalcOpenDevice(String devicename);
+	static native long nalcOpenDevice(String devicename);
 
 	/**
 	 * The <code>alcCloseDevice</code> function allows the application (i.e. the client program) to
 	* disconnect from a device (i.e. the server).
-	* 
+	*
 	* If deviceHandle is <code>null</code> or invalid, an <code>ALC_INVALID_DEVICE</code> error will be
 	* generated. Once closed, a deviceHandle is invalid.
 	 *
@@ -226,15 +226,15 @@ public final class ALC10 {
 			devices.remove(new Long(device.device));
 		}
 		return result;
-		
+
 	}
-	native static boolean nalcCloseDevice(long device);
+	static native boolean nalcCloseDevice(long device);
 
 	/**
 	 * A context is created using <code>alcCreateContext</code>. The device parameter has to be a valid
 	* device. The attribute list can be <code>null</code>, or a zero terminated list of integer pairs
 	* composed of valid ALC attribute tokens and requested values.
-	* 
+	*
 	* Context creation will fail if the application requests attributes that, by themselves,
 	* can not be provided. Context creation will fail if the combination of specified
 	* attributes can not be provided. Context creation will fail if a specified attribute, or
@@ -248,25 +248,25 @@ public final class ALC10 {
 	public static ALCcontext alcCreateContext(ALCdevice device, IntBuffer attrList) {
 		long context_address = nalcCreateContext(getDevice(device), attrList);
 		Util.checkALCError(device);
-		
+
 		if(context_address != 0) {
 			ALCcontext context = new ALCcontext(context_address);
 			synchronized (ALC10.contexts) {
-				contexts.put(new Long(context_address), context);
+				contexts.put(context_address, context);
 				device.addContext(context);
 			}
 			return context;
 		}
 		return null;
 	}
-	native static long nalcCreateContext(long device, IntBuffer attrList);
+	static native long nalcCreateContext(long device, IntBuffer attrList);
 
 	/**
 	 * To make a Context current with respect to AL Operation (state changes by issueing
 	* commands), <code>alcMakeContextCurrent</code> is used. The context parameter can be <code>null</code>
 	* or a valid context pointer. The operation will apply to the device that the context
 	* was created for.
-	* 
+	*
 	* For each OS process (usually this means for each application), only one context can
 	* be current at any given time. All AL commands apply to the current context.
 	* Commands that affect objects shared among contexts (e.g. buffers) have side effects
@@ -278,7 +278,7 @@ public final class ALC10 {
 	public static int alcMakeContextCurrent(ALCcontext context) {
 		return nalcMakeContextCurrent(getContext(context));
 	}
-	native static int nalcMakeContextCurrent(long context);
+	static native int nalcMakeContextCurrent(long context);
 
 	/**
 	 * The current context is the only context accessible to state changes by AL commands
@@ -294,7 +294,7 @@ public final class ALC10 {
 	public static void alcProcessContext(ALCcontext context) {
 		nalcProcessContext(getContext(context));
 	}
-	native static void nalcProcessContext(long context);
+	static native void nalcProcessContext(long context);
 
 	/**
 	 * The application can query for, and obtain an handle to, the current context for the
@@ -307,12 +307,12 @@ public final class ALC10 {
 		long context_address = nalcGetCurrentContext();
 		if(context_address != 0) {
 			synchronized (ALC10.contexts) {
-				context = (ALCcontext) ALC10.contexts.get(new Long(context_address));
+				context = ALC10.contexts.get(context_address);
 			}
 		}
 		return context;
 	}
-	native static long nalcGetCurrentContext();
+	static native long nalcGetCurrentContext();
 
 	/**
 	 * The application can query for, and obtain an handle to, the device of a given context.
@@ -324,19 +324,19 @@ public final class ALC10 {
 		long device_address = nalcGetContextsDevice(getContext(context));
 		if (device_address != 0) {
 			synchronized (ALC10.devices) {
-				device = (ALCdevice) ALC10.devices.get(new Long(device_address));
+				device = ALC10.devices.get(device_address);
 			}
 		}
 		return device;
-	}	
-	native static long nalcGetContextsDevice(long context);
+	}
+	static native long nalcGetContextsDevice(long context);
 
 	/**
 	 * The application can suspend any context from processing (including the current
 	 * one). To indicate that a context should be suspended from processing (i.e. that
 	 * internal execution state like offset increments is not supposed to be changed), the
 	 * application has to use <code>alcSuspendContext</code>.
-	 * 
+	 *
 	 * Repeated calls to <code>alcSuspendContext</code> are legal, and do not affect a context that is
 	 * already marked as suspended. The default state of a context created by
 	 * <code>alcCreateContext</code> is that it is marked as suspended.
@@ -346,7 +346,7 @@ public final class ALC10 {
 	public static void alcSuspendContext(ALCcontext context) {
 		nalcSuspendContext(getContext(context));
 	}
-	native static void nalcSuspendContext(long context);
+	static native void nalcSuspendContext(long context);
 
 	/**
 	 * The correct way to destroy a context is to first release it using <code>alcMakeCurrent</code> and
@@ -362,15 +362,15 @@ public final class ALC10 {
 			context.setInvalid();
 		}
 	}
-	native static void nalcDestroyContext(long context);
+	static native void nalcDestroyContext(long context);
 
 	/**
 	 * ALC uses the same conventions and mechanisms as AL for error handling. In
 	* particular, ALC does not use conventions derived from X11 (GLX) or Windows
 	* (WGL). The <code>alcGetError</code> function can be used to query ALC errors.
-	* 
+	*
 	* Error conditions are specific to the device.
-	* 
+	*
 	* ALC_NO_ERROR - The device handle or specifier does name an accessible driver/server.
 	* <code>ALC_INVALID_DEVICE</code> - The Context argument does not name a valid context.
 	* <code>ALC_INVALID_CONTEXT</code> - The Context argument does not name a valid context.
@@ -382,7 +382,7 @@ public final class ALC10 {
 	public static int alcGetError(ALCdevice device) {
 		return nalcGetError(getDevice(device));
 	}
-	native static int nalcGetError(long device);
+	static native int nalcGetError(long device);
 
 	/**
 	* Verify that a given extension is available for the current context and the device it
@@ -398,13 +398,13 @@ public final class ALC10 {
 		Util.checkALCError(device);
 		return result;
 	}
-	native static boolean nalcIsExtensionPresent(long device, String extName);
+	static native boolean nalcIsExtensionPresent(long device, String extName);
 
 	/**
 	 * Enumeration/token values are device independend, but tokens defined for
 	* extensions might not be present for a given device. But only the tokens defined
 	* by the AL core are guaranteed. Availability of extension tokens dependends on the ALC extension.
-	* 
+	*
 	* Specifying a <code>null</code> name parameter will cause an <code>ALC_INVALID_VALUE</code> error.
 	 *
 	 * @param enumName name of enum to find
@@ -415,8 +415,8 @@ public final class ALC10 {
 		Util.checkALCError(device);
 		return result;
 	}
-	native static int nalcGetEnumValue(long device, String enumName);
-	
+	static native int nalcGetEnumValue(long device, String enumName);
+
 	static long getDevice(ALCdevice device) {
 		if(device != null) {
 			Util.checkALCValidDevice(device);
@@ -424,13 +424,13 @@ public final class ALC10 {
 		}
 		return 0L;
 	}
-	
+
 	static long getContext(ALCcontext context) {
 		if(context != null) {
 			Util.checkALCValidContext(context);
 			return context.context;
 		}
 		return 0L;
-	}	
+	}
 
 }
