@@ -33,6 +33,7 @@ package org.lwjgl.opengl;
 
 import org.lwjgl.LWJGLException;
 import org.lwjgl.LWJGLUtil;
+import org.lwjgl.PointerBuffer;
 import org.lwjgl.Sys;
 
 import java.awt.*;
@@ -47,14 +48,14 @@ import java.awt.event.HierarchyListener;
  * <p/>
  *
  * @author $Author: spasi $
- *         $Id: AWTGLCanvas.java 3334 2010-04-22 23:21:48Z spasi $
- * @version $Revision: 3334 $
+ *         $Id: AWTGLCanvas.java 3418 2010-09-28 21:11:35Z spasi $
+ * @version $Revision: 3418 $
  */
 public class AWTGLCanvas extends Canvas implements DrawableLWJGL, ComponentListener, HierarchyListener {
 
 	private static final long serialVersionUID = 1L;
 
-	private final static AWTCanvasImplementation implementation;
+	private static final AWTCanvasImplementation implementation;
 	private boolean update_context;
 	private Object SYNC_LOCK = new Object();
 
@@ -258,6 +259,14 @@ public class AWTGLCanvas extends Canvas implements DrawableLWJGL, ComponentListe
 		}
 	}
 
+	public final void setCLSharingProperties(final PointerBuffer properties) throws LWJGLException {
+		synchronized ( SYNC_LOCK ) {
+			if ( context == null )
+				throw new IllegalStateException("Canvas not yet displayable");
+			context.setCLSharingProperties(properties);
+		}
+	}
+
 	/**
 	 * Override this to do initialising of the context.
 	 * It will be called once from paint(), immediately after
