@@ -33,11 +33,15 @@ package org.lwjgl.opengl;
 
 import org.lwjgl.LWJGLException;
 import org.lwjgl.LWJGLUtil;
+import org.lwjgl.PointerBuffer;
 import org.lwjgl.Sys;
+import org.lwjgl.opencl.KHRGLSharing;
 
 import java.nio.ByteBuffer;
 import java.nio.IntBuffer;
 
+import static org.lwjgl.opengl.GL11.*;
+
 /**
  * <p/>
  * Context encapsulates an OpenGL context.
@@ -46,16 +50,16 @@ import java.nio.IntBuffer;
  * This class is thread-safe.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3332 $
- *          $Id: Context.java 3332 2010-04-20 18:21:05Z spasi $
+ * @version $Revision: 3418 $
+ *          $Id: Context.java 3418 2010-09-28 21:11:35Z spasi $
  */
 final class Context {
 
 	/** The platform specific implementation of context methods */
-	private final static ContextImplementation implementation;
+	private static final ContextImplementation implementation;
 
 	/** The current Context */
-	private final static ThreadLocal current_context_local = new ThreadLocal();
+	private static final ThreadLocal<Context> current_context_local = new ThreadLocal<Context>();
 
 	/** Handle to the native GL rendering context */
 	private final ByteBuffer handle;
@@ -99,7 +103,7 @@ final class Context {
 	}
 
 	static Context getCurrentContext() {
-		return (Context)current_context_local.get();
+		return current_context_local.get();
 	}
 
 	/** Create a context with the specified peer info and shared context */
@@ -206,6 +210,7 @@ final class Context {
 			try {
 				releaseDrawable();
 				implementation.destroy(peer_info, handle);
+				CallbackUtil.unregisterCallbacks(this);
 				destroyed = true;
 				thread = null;
 				GLContext.unloadOpenGLLibrary();
@@ -245,15 +250,37 @@ final class Context {
 			return;
 		destroy_requested = true;
 		boolean was_current = isCurrent();
-		int error = GL11.GL_NO_ERROR;
+		int error = GL_NO_ERROR;
 		if ( was_current ) {
 			if ( GLContext.getCapabilities() != null && GLContext.getCapabilities().OpenGL11 )
-				error = GL11.glGetError();
+				error = glGetError();
 			releaseCurrentContext();
 		}
 		checkDestroy();
-		if ( was_current && error != GL11.GL_NO_ERROR )
+		if ( was_current && error != GL_NO_ERROR )
 			throw new OpenGLException(error);
 	}
 
+	public synchronized void setCLSharingProperties(final PointerBuffer properties) throws LWJGLException {
+		final ByteBuffer peer_handle = peer_info.lockAndGetHandle();
+		try {
+			switch ( LWJGLUtil.getPlatform() ) {
+				case LWJGLUtil.PLATFORM_WINDOWS:
+					final WindowsContextImplementation implWindows = (WindowsContextImplementation)implementation;
+					properties.put(KHRGLSharing.CL_GL_CONTEXT_KHR).put(implWindows.getHGLRC(handle));
+					properties.put(KHRGLSharing.CL_WGL_HDC_KHR).put(implWindows.getHDC(peer_handle));
+					break;
+				case LWJGLUtil.PLATFORM_LINUX:
+					final LinuxContextImplementation implLinux = (LinuxContextImplementation)implementation;
+					properties.put(KHRGLSharing.CL_GL_CONTEXT_KHR).put(implLinux.getGLXContext(handle));
+					properties.put(KHRGLSharing.CL_GLX_DISPLAY_KHR).put(implLinux.getDisplay(peer_handle));
+					break;
+				default:
+					throw new UnsupportedOperationException("CL/GL context sharing is not supposed on this platform.");
+			}
+		} finally {
+			peer_info.unlock();
+		}
+	}
+
 }
\ No newline at end of file
