@@ -32,6 +32,7 @@
 package org.lwjgl.opengl;
 
 import org.lwjgl.LWJGLException;
+import org.lwjgl.PointerBuffer;
 
 /**
  * The Drawable interface describes an OpenGL drawable with an associated
@@ -62,4 +63,15 @@ public interface Drawable {
 	/** Destroys the Drawable. */
 	void destroy();
 
+	/**
+	 * Sets the appropriate khr_gl_sharing properties in the target <code>PointerBuffer</code>,
+	 * so that if it is used in a <code>clCreateContext(FromType)</code> call, the created CL
+	 * context will be sharing objects with this <code>Drawable</code>'s GL context. After a
+	 * call to this method, the target buffer position will have advanced by 2 to 4 positions,
+	 * depending on the implementation.
+	 *
+	 * @param properties The target properties buffer. It must have at least 4 positions remaining.
+	 */
+	void setCLSharingProperties(PointerBuffer properties) throws LWJGLException;
+
 }
