@@ -32,11 +32,18 @@
 package org.lwjgl.opengl;
 
 import java.nio.Buffer;
-import java.nio.IntBuffer;
 
 import org.lwjgl.BufferUtils;
 import org.lwjgl.LWJGLUtil;
 
+import static org.lwjgl.opengl.ARBBufferObject.*;
+import static org.lwjgl.opengl.ATIVertexArrayObject.*;
+import static org.lwjgl.opengl.EXTAbgr.*;
+import static org.lwjgl.opengl.EXTBgra.*;
+import static org.lwjgl.opengl.EXTDirectStateAccess.*;
+import static org.lwjgl.opengl.GL11.*;
+import static org.lwjgl.opengl.GL15.*;
+
 /**
  * A class to check buffer boundaries in GL methods. Many GL
  * methods read data from the GL into a native Buffer at its current position. If there is unsufficient space in the buffer when
@@ -47,8 +54,8 @@ import org.lwjgl.LWJGLUtil;
  * Thrown by the debug build library of the LWJGL if any OpenGL operation causes an error.
  *
  * @author cix_foo <cix_foo@users.sourceforge.net>
- * @version $Revision: 3334 $
- * $Id: GLChecks.java 3334 2010-04-22 23:21:48Z spasi $
+ * @version $Revision: 3459 $
+ * $Id: GLChecks.java 3459 2010-11-29 17:21:05Z spasi $
  */
 class GLChecks {
 
@@ -56,83 +63,79 @@ class GLChecks {
 	private GLChecks() {
 	}
 
-	static References getReferences(ContextCapabilities caps) {
-		return StateTracker.getReferencesStack(caps).getReferences();
-	}
-
 	static int getBufferObjectSize(ContextCapabilities caps, int buffer_enum) {
-		return GL15.glGetBufferParameter(buffer_enum, GL15.GL_BUFFER_SIZE);
+		return glGetBufferParameter(buffer_enum, GL_BUFFER_SIZE);
 	}
 
 	static int getBufferObjectSizeARB(ContextCapabilities caps, int buffer_enum) {
-		return ARBBufferObject.glGetBufferParameterARB(buffer_enum, ARBBufferObject.GL_BUFFER_SIZE_ARB);
+		return glGetBufferParameterARB(buffer_enum, GL_BUFFER_SIZE_ARB);
 	}
 
 	static int getBufferObjectSizeATI(ContextCapabilities caps, int buffer) {
-		return ATIVertexArrayObject.glGetObjectBufferATI(buffer, ATIVertexArrayObject.GL_OBJECT_BUFFER_SIZE_ATI);
+		return glGetObjectBufferATI(buffer, GL_OBJECT_BUFFER_SIZE_ATI);
 	}
 
 	static int getNamedBufferObjectSize(ContextCapabilities caps, int buffer) {
-		return EXTDirectStateAccess.glGetNamedBufferParameterEXT(buffer, GL15.GL_BUFFER_SIZE);
+		return glGetNamedBufferParameterEXT(buffer, GL_BUFFER_SIZE);
 	}
 
 	/** Helper method to ensure that array buffer objects are disabled. If they are enabled, we'll throw an OpenGLException */
 	static void ensureArrayVBOdisabled(ContextCapabilities caps) {
-		if( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().arrayBuffer != 0 )
+		if( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).arrayBuffer != 0 )
 			throw new OpenGLException("Cannot use Buffers when Array Buffer Object is enabled");
 	}
 
 	/** Helper method to ensure that array buffer objects are enabled. If they are disabled, we'll throw an OpenGLException */
 	static void ensureArrayVBOenabled(ContextCapabilities caps) {
-		if( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().arrayBuffer == 0 )
+		if( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).arrayBuffer == 0 )
 			throw new OpenGLException("Cannot use offsets when Array Buffer Object is disabled");
 	}
 
 	/** Helper method to ensure that element array buffer objects are disabled. If they are enabled, we'll throw an OpenGLException */
 	static void ensureElementVBOdisabled(ContextCapabilities caps) {
-		if( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().elementArrayBuffer != 0 )
+		if( LWJGLUtil.CHECKS && StateTracker.getElementArrayBufferBound(caps) != 0 )
 			throw new OpenGLException("Cannot use Buffers when Element Array Buffer Object is enabled");
 	}
 
 	/** Helper method to ensure that element array buffer objects are enabled. If they are disabled, we'll throw an OpenGLException */
 	static void ensureElementVBOenabled(ContextCapabilities caps) {
-		if( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().elementArrayBuffer == 0 )
+		if( LWJGLUtil.CHECKS && StateTracker.getElementArrayBufferBound(caps) == 0 )
 			throw new OpenGLException("Cannot use offsets when Element Array Buffer Object is disabled");
 	}
 
 	/** Helper method to ensure that array buffer objects are disabled. If they are enabled, we'll throw an OpenGLException */
 	static void ensureIndirectBOdisabled(ContextCapabilities caps) {
-		if ( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().indirectBuffer != 0 )
+		if ( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).indirectBuffer != 0 )
 			throw new OpenGLException("Cannot use Buffers when Draw Indirect Object is enabled");
 	}
 
 	/** Helper method to ensure that array buffer objects are enabled. If they are disabled, we'll throw an OpenGLException */
 	static void ensureIndirectBOenabled(ContextCapabilities caps) {
-		if ( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().indirectBuffer == 0 )
+		if ( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).indirectBuffer == 0 )
 			throw new OpenGLException("Cannot use offsets when Draw Indirect Object is disabled");
 	}
 
 	/** Helper method to ensure that pixel pack buffer objects are disabled. If they are enabled, we'll throw an OpenGLException */
 	static void ensurePackPBOdisabled(ContextCapabilities caps) {
-		if ( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().pixelPackBuffer != 0 )
+		if ( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).pixelPackBuffer != 0 )
 			throw new OpenGLException("Cannot use Buffers when Pixel Pack Buffer Object is enabled");
 	}
 
 	/** Helper method to ensure that pixel pack buffer objects are enabled. If they are disabled, we'll throw an OpenGLException */
 	static void ensurePackPBOenabled(ContextCapabilities caps) {
-		if ( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().pixelPackBuffer == 0 )
+		if ( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).pixelPackBuffer == 0 )
 			throw new OpenGLException("Cannot use offsets when Pixel Pack Buffer Object is disabled");
 	}
 
 	/** Helper method to ensure that pixel unpack buffer objects are disabled. If they are enabled, we'll throw an OpenGLException */
 	static void ensureUnpackPBOdisabled(ContextCapabilities caps) {
-		if ( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().pixelUnpackBuffer != 0 )
+		if ( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).pixelUnpackBuffer != 0 )
 			throw new OpenGLException("Cannot use Buffers when Pixel Unpack Buffer Object is enabled");
 	}
 
 	/** Helper method to ensure that pixel unpack buffer objects are enabled. If they are disabled, we'll throw an OpenGLException */
 	static void ensureUnpackPBOenabled(ContextCapabilities caps) {
-		if ( LWJGLUtil.CHECKS && StateTracker.getReferencesStack(caps).getReferences().pixelUnpackBuffer == 0 )
+		if ( LWJGLUtil.CHECKS && StateTracker.getReferences(caps).pixelUnpackBuffer == 0 )
 			throw new OpenGLException("Cannot use offsets when Pixel Unpack Buffer Object is disabled");
 	}
 
@@ -193,17 +196,17 @@ class GLChecks {
 	private static int calculateBytesPerPixel(int format, int type) {
 		int bpe;
 		switch ( type ) {
-			case GL11.GL_UNSIGNED_BYTE:
-			case GL11.GL_BYTE:
+			case GL_UNSIGNED_BYTE:
+			case GL_BYTE:
 				bpe = 1;
 				break;
-			case GL11.GL_UNSIGNED_SHORT:
-			case GL11.GL_SHORT:
+			case GL_UNSIGNED_SHORT:
+			case GL_SHORT:
 				bpe = 2;
 				break;
-			case GL11.GL_UNSIGNED_INT:
-			case GL11.GL_INT:
-			case GL11.GL_FLOAT:
+			case GL_UNSIGNED_INT:
+			case GL_INT:
+			case GL_FLOAT:
 				bpe = 4;
 				break;
 			default :
@@ -213,21 +216,21 @@ class GLChecks {
 		}
 		int epp;
 		switch ( format ) {
-			case GL11.GL_LUMINANCE:
-			case GL11.GL_ALPHA:
+			case GL_LUMINANCE:
+			case GL_ALPHA:
 				epp = 1;
 				break;
 
-			case GL11.GL_LUMINANCE_ALPHA:
+			case GL_LUMINANCE_ALPHA:
 				epp = 2;
 				break;
-			case GL11.GL_RGB:
-			case EXTBgra.GL_BGR_EXT:
+			case GL_RGB:
+			case GL_BGR_EXT:
 				epp = 3;
 				break;
-			case GL11.GL_RGBA:
-			case EXTAbgr.GL_ABGR_EXT:
-			case EXTBgra.GL_BGRA_EXT:
+			case GL_RGBA:
+			case GL_ABGR_EXT:
+			case GL_BGRA_EXT:
 				epp = 4;
 				break;
 			default :
