@@ -1,31 +1,31 @@
-/* 
+/*
  * Copyright (c) 2002-2008 LWJGL Project
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are 
+ * modification, are permitted provided that the following conditions are
  * met:
- * 
- * * Redistributions of source code must retain the above copyright 
+ *
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
  *
  * * Redistributions in binary form must reproduce the above copyright
  *   notice, this list of conditions and the following disclaimer in the
  *   documentation and/or other materials provided with the distribution.
  *
- * * Neither the name of 'LWJGL' nor the names of 
- *   its contributors may be used to endorse or promote products derived 
+ * * Neither the name of 'LWJGL' nor the names of
+ *   its contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
  * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
- * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
- * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
@@ -36,17 +36,18 @@ import org.lwjgl.input.Keyboard;
 import org.lwjgl.input.Mouse;
 import org.lwjgl.opengl.Display;
 import org.lwjgl.opengl.DisplayMode;
-import org.lwjgl.opengl.GL11;
-import org.lwjgl.util.glu.GLU;
 import org.lwjgl.util.vector.Vector2f;
 
+import static org.lwjgl.opengl.GL11.*;
+import static org.lwjgl.util.glu.GLU.*;
+
 /**
- * 
+ *
  * Tests switching between windowed and fullscreen
- * 
+ *
  * @author Brian Matzon <brian@matzon.dk>
- * @version $Revision: 3365 $
- * $Id: FullScreenWindowedTest.java 3365 2010-07-04 18:24:53Z spasi $
+ * @version $Revision: 3418 $
+ * $Id: FullScreenWindowedTest.java 3418 2010-09-28 21:11:35Z spasi $
  */
 public class FullScreenWindowedTest {
 	/** Intended deiplay mode */
@@ -145,23 +146,23 @@ public class FullScreenWindowedTest {
 	}
 	private void render() {
 		//clear background
-		GL11.glClear(GL11.GL_COLOR_BUFFER_BIT);
+		glClear(GL_COLOR_BUFFER_BIT);
 		// draw white quad
-		GL11.glPushMatrix();
+		glPushMatrix();
 		{
-			GL11.glTranslatef(quadPosition.x, quadPosition.y, 0);
-			GL11.glRotatef(angle, 0.0f, 0.0f, 1.0f);
-			GL11.glColor3f(1.0f, 1.0f, 1.0f);
-			GL11.glBegin(GL11.GL_QUADS);
+			glTranslatef(quadPosition.x, quadPosition.y, 0);
+			glRotatef(angle, 0.0f, 0.0f, 1.0f);
+			glColor3f(1.0f, 1.0f, 1.0f);
+			glBegin(GL_QUADS);
 			{
-				GL11.glVertex2i(-50, -50);
-				GL11.glVertex2i(50, -50);
-				GL11.glVertex2i(50, 50);
-				GL11.glVertex2i(-50, 50);
+				glVertex2i(-50, -50);
+				glVertex2i(50, -50);
+				glVertex2i(50, 50);
+				glVertex2i(-50, 50);
 			}
-			GL11.glEnd();
+			glEnd();
 		}
-		GL11.glPopMatrix();
+		glPopMatrix();
 	}
 	/**
 	 * Processes keyboard input
@@ -235,7 +236,7 @@ public class FullScreenWindowedTest {
 
 	/**
 	 * Retrieves a displaymode, if one such is available
-	 * 
+	 *
 	 * @param width
 	 *            Required width
 	 * @param height
@@ -246,9 +247,9 @@ public class FullScreenWindowedTest {
 	 */
 	private DisplayMode findDisplayMode(int width, int height, int bpp) throws LWJGLException {
 		DisplayMode[] modes = Display.getAvailableDisplayModes();
-		for (int i = 0; i < modes.length; i++) {
-			if (modes[i].getWidth() == width && modes[i].getHeight() == height && modes[i].getBitsPerPixel() >= bpp && modes[i].getFrequency() <= 60) {
-				return modes[i];
+		for ( DisplayMode mode : modes ) {
+			if ( mode.getWidth() == width && mode.getHeight() == height && mode.getBitsPerPixel() >= bpp && mode.getFrequency() <= 60 ) {
+				return mode;
 			}
 		}
 		return Display.getDesktopDisplayMode();
@@ -258,14 +259,14 @@ public class FullScreenWindowedTest {
 	 */
 	private void glInit() {
 		// Go into orthographic projection mode.
-		GL11.glMatrixMode(GL11.GL_PROJECTION);
-		GL11.glLoadIdentity();
-		GLU.gluOrtho2D(0, mode.getWidth(), 0, mode.getHeight());
-		GL11.glMatrixMode(GL11.GL_MODELVIEW);
-		GL11.glLoadIdentity();
-		GL11.glViewport(0, 0, mode.getWidth(), mode.getHeight());
+		glMatrixMode(GL_PROJECTION);
+		glLoadIdentity();
+		gluOrtho2D(0, mode.getWidth(), 0, mode.getHeight());
+		glMatrixMode(GL_MODELVIEW);
+		glLoadIdentity();
+		glViewport(0, 0, mode.getWidth(), mode.getHeight());
 		//set clear color to black
-		GL11.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
+		glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
 		//sync frame (only works on windows)
 		Display.setVSyncEnabled(true);
 	}
