@@ -37,17 +37,18 @@ package org.lwjgl.util.generator;
  * according to the remaining() of a Buffer parameter.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3355 $
- * $Id: AutoSize.java 3355 2010-05-27 22:56:29Z spasi $
+ * @version $Revision: 3412 $
+ * $Id: AutoSize.java 3412 2010-09-26 23:43:24Z spasi $
  */
 
 import java.lang.annotation.Target;
 import java.lang.annotation.ElementType;
 
 @Auto
-@Target(ElementType.PARAMETER)
+@Target({ElementType.METHOD,ElementType.PARAMETER})
 public @interface AutoSize {
 	String value(); // The name of the Buffer parameter
 	String expression() default ""; // This value is added after the argument
 	boolean canBeNull() default false; // When this is true and the Buffer parameter is null, 0 will be used.
+	boolean isNative() default false; // When this is true, auto-sizing will be performed in native code.
 }
