@@ -32,6 +32,7 @@
 package org.lwjgl.opengl;
 
 import org.lwjgl.util.generator.*;
+import org.lwjgl.util.generator.opengl.*;
 
 import java.nio.*;
 
@@ -519,11 +520,11 @@ public interface EXT_direct_state_access {
     value parameters
 	 */
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
+	@Optional(reason = "AMD does not expose this (last driver checked: 10.9)")
 	@Dependent("OpenGL30")
 	void glEnableClientStateiEXT(@GLenum int array, @GLuint int index);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
+	@Optional(reason = "AMD does not expose this (last driver checked: 10.9)")
 	@Dependent("OpenGL30")
 	void glDisableClientStateiEXT(@GLenum int array, @GLuint int index);
 
@@ -565,7 +566,7 @@ public interface EXT_direct_state_access {
     and before state value parameters
 	 */
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
+	@Optional(reason = "AMD does not expose this (last driver checked: 10.9)")
 	@Dependent("OpenGL30")
 	@StripPostfix("params")
 	void glGetFloati_vEXT(@GLenum int pname, @GLuint int index, @OutParameter @Check("16") FloatBuffer params);
@@ -576,7 +577,7 @@ public interface EXT_direct_state_access {
 	@StripPostfix("params")
 	void glGetFloati_vEXT2(@GLenum int pname, @GLuint int index, @OutParameter FloatBuffer params);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
+	@Optional(reason = "AMD does not expose this (last driver checked: 10.9)")
 	@Dependent("OpenGL30")
 	@StripPostfix("params")
 	void glGetDoublei_vEXT(@GLenum int pname, @GLuint int index, @OutParameter @Check("16") DoubleBuffer params);
@@ -587,7 +588,7 @@ public interface EXT_direct_state_access {
 	@StripPostfix("params")
 	void glGetDoublei_vEXT2(@GLenum int pname, @GLuint int index, @OutParameter DoubleBuffer params);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
+	@Optional(reason = "AMD does not expose this (last driver checked: 10.9)")
 	@Dependent("OpenGL30")
 	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetPointeri_vEXT(@GLenum int pname, @GLuint int index, @Result @GLvoid ByteBuffer params);
@@ -598,32 +599,39 @@ public interface EXT_direct_state_access {
     TODO: Why 1.2.1 and not EXT_draw_buffers2?
 	 */
 
-	@Dependent("GL_EXT_draw_buffers2")
+	@Reuse("EXTDrawBuffers2")
+	@Dependent("OpenGL13")
 	void glEnableIndexedEXT(@GLenum int cap, @GLuint int index);
 
-	@Dependent("GL_EXT_draw_buffers2")
+	@Reuse("EXTDrawBuffers2")
+	@Dependent("OpenGL13")
 	void glDisableIndexedEXT(@GLenum int cap, @GLuint int index);
 
-	@Dependent("GL_EXT_draw_buffers2")
+	@Reuse("EXTDrawBuffers2")
+	@Dependent("OpenGL13")
 	boolean glIsEnabledIndexedEXT(@GLenum int cap, @GLuint int index);
 
-	@Dependent("GL_EXT_draw_buffers2")
+	@Reuse("EXTDrawBuffers2")
+	@Dependent("OpenGL13")
 	@StripPostfix("params")
 	void glGetIntegerIndexedvEXT(@GLenum int pname, @GLuint int index, @OutParameter @Check("16") IntBuffer params);
 
+	@Reuse("EXTDrawBuffers2")
 	@Alternate("glGetIntegerIndexedvEXT")
 	@GLreturn("params")
-	@Dependent("GL_EXT_draw_buffers2")
+	@Dependent("OpenGL13")
 	@StripPostfix("params")
 	void glGetIntegerIndexedvEXT2(@GLenum int pname, @GLuint int index, @OutParameter IntBuffer params);
 
-	@Dependent("GL_EXT_draw_buffers2")
+	@Reuse("EXTDrawBuffers2")
+	@Dependent("OpenGL13")
 	@StripPostfix("params")
-	void glGetBooleanIndexedvEXT(@GLenum int pname, @GLuint int index, @OutParameter @Check("16") @GLboolean ByteBuffer params);
+	void glGetBooleanIndexedvEXT(@GLenum int pname, @GLuint int index, @OutParameter @Check("4") @GLboolean ByteBuffer params);
 
+	@Reuse("EXTDrawBuffers2")
 	@Alternate("glGetBooleanIndexedvEXT")
 	@GLreturn("params")
-	@Dependent("GL_EXT_draw_buffers2")
+	@Dependent("OpenGL13")
 	@StripPostfix("params")
 	void glGetBooleanIndexedvEXT2(@GLenum int pname, @GLuint int index, @OutParameter @GLboolean ByteBuffer params);
 
@@ -809,6 +817,7 @@ public interface EXT_direct_state_access {
 	                                       @GLvoid
 	                                       ByteBuffer data);
 
+
 	@Dependent("OpenGL13")
 	void glGetCompressedMultiTexImageEXT(@GLenum int texunit, @GLenum int target, int level,
 	                                     @OutParameter
@@ -818,15 +827,6 @@ public interface EXT_direct_state_access {
 	                                     @GLshort
 	                                     @GLint Buffer img);
 
-	@Dependent("OpenGL13")
-	void glGetCompressedTexImage(@GLenum int target, int lod,
-	                             @OutParameter
-	                             @BufferObject(BufferKind.PackPBO)
-	                             @Check
-	                             @GLbyte
-	                             @GLshort
-	                             @GLint Buffer img);
-
 	/*
 	OpenGL 1.3: New transpose matrix commands add "Matrix" suffix
     to name, drops "Matrix" suffix from name, and add initial "enum
@@ -905,7 +905,7 @@ public interface EXT_direct_state_access {
 	@Dependent("OpenGL15")
 	@CachedResult
 	@GLvoid
-	@AutoResultSize("GLChecks.getNamedBufferObjectSize(caps, buffer)")
+	@AutoSize("GLChecks.getNamedBufferObjectSize(caps, buffer)")
 	ByteBuffer glMapNamedBufferEXT(@GLuint int buffer, @GLenum int access);
 
 	@Dependent("OpenGL15")
@@ -923,7 +923,7 @@ public interface EXT_direct_state_access {
 
 	@Dependent("OpenGL15")
 	@StripPostfix("params")
-	@AutoResultSize("GLChecks.getNamedBufferObjectSize(caps, buffer)")
+	@AutoSize("GLChecks.getNamedBufferObjectSize(caps, buffer)")
 	void glGetNamedBufferPointervEXT(@GLuint int buffer, @GLenum int pname, @OutParameter @Result @GLvoid ByteBuffer params);
 
 	@Dependent("OpenGL15")
@@ -1075,7 +1075,7 @@ public interface EXT_direct_state_access {
 	@Alternate("glTextureParameterIivEXT")
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("param")
-	void glTextureParameterIivEXT(@GLuint int texture, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtils.getBufferInt().put(0, param), 0", keepParam = true) int param);
+	void glTextureParameterIivEXT(@GLuint int texture, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtil.getBufferInt().put(0, param), 0", keepParam = true) int param);
 
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("params")
@@ -1084,7 +1084,7 @@ public interface EXT_direct_state_access {
 	@Alternate("glTextureParameterIuivEXT")
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("param")
-	void glTextureParameterIuivEXT(@GLuint int texture, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtils.getBufferInt().put(0, param), 0", keepParam = true) @GLuint int param);
+	void glTextureParameterIuivEXT(@GLuint int texture, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtil.getBufferInt().put(0, param), 0", keepParam = true) @GLuint int param);
 
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("params")
@@ -1119,7 +1119,7 @@ public interface EXT_direct_state_access {
 	@Alternate("glMultiTexParameterIivEXT")
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("param")
-	void glMultiTexParameterIivEXT(@GLenum int texunit, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtils.getBufferInt().put(0, param), 0", keepParam = true) int param);
+	void glMultiTexParameterIivEXT(@GLenum int texunit, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtil.getBufferInt().put(0, param), 0", keepParam = true) int param);
 
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("params")
@@ -1128,7 +1128,7 @@ public interface EXT_direct_state_access {
 	@Alternate("glMultiTexParameterIuivEXT")
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("param")
-	void glMultiTexParameterIuivEXT(@GLenum int texunit, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtils.getBufferInt().put(0, param), 0", keepParam = true) int param);
+	void glMultiTexParameterIuivEXT(@GLenum int texunit, @GLenum int target, @GLenum int pname, @Constant(value = "APIUtil.getBufferInt().put(0, param), 0", keepParam = true) int param);
 
 	@Dependent("GL_EXT_texture_integer")
 	@StripPostfix("params")
@@ -1343,7 +1343,6 @@ public interface EXT_direct_state_access {
 	OpenGL 3.1: New buffer data copy command
 	 */
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL31,GL_ARB_copy_buffer")
 	void glNamedCopyBufferSubDataEXT(@GLuint int readBuffer, @GLuint int writeBuffer, @GLintptr long readoffset, @GLintptr long writeoffset, @GLsizeiptr long size);
 
@@ -1387,55 +1386,44 @@ public interface EXT_direct_state_access {
 	and change the final parameter from "const void *" to "intptr offset"
 	 */
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArrayVertexOffsetEXT(@GLuint int vaobj, @GLuint int buffer, int size, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArrayColorOffsetEXT(@GLuint int vaobj, @GLuint int buffer, int size, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArrayEdgeFlagOffsetEXT(@GLuint int vaobj, @GLuint int buffer, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glVertexArrayIndexOffsetEXT(@GLuint int vaobj, @GLuint int buffer, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArrayNormalOffsetEXT(@GLuint int vaobj, @GLuint int buffer, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArrayTexCoordOffsetEXT(@GLuint int vaobj, @GLuint int buffer, int size, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArrayMultiTexCoordOffsetEXT(@GLuint int vaobj, @GLuint int buffer, @GLenum int texunit, int size, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArrayFogCoordOffsetEXT(@GLuint int vaobj, @GLuint int buffer, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@DeprecatedGL
 	void glVertexArraySecondaryColorOffsetEXT(@GLuint int vaobj, @GLuint int buffer, int size, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glVertexArrayVertexAttribOffsetEXT(@GLuint int vaobj, @GLuint int buffer, @GLuint int index, int size, @GLenum int type, boolean normalized, @GLsizei int stride, @GLintptr long offset);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glVertexArrayVertexAttribIOffsetEXT(@GLuint int vaobj, @GLuint int buffer, @GLuint int index, int size, @GLenum int type, @GLsizei int stride, @GLintptr long offset);
 
@@ -1445,11 +1433,9 @@ public interface EXT_direct_state_access {
 	"uint vaobj" parameter
 	 */
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glEnableVertexArrayEXT(@GLuint int vaobj, @GLenum int array);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glDisableVertexArrayEXT(@GLuint int vaobj, @GLenum int array);
 
@@ -1459,11 +1445,9 @@ public interface EXT_direct_state_access {
 	and add an initial "uint vaobj" parameter
 	 */
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glEnableVertexArrayAttribEXT(@GLuint int vaobj, @GLuint int index);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glDisableVertexArrayAttribEXT(@GLuint int vaobj, @GLuint int index);
 
@@ -1471,7 +1455,6 @@ public interface EXT_direct_state_access {
 	OpenGL 3.0: New queries for vertex array objects
 	 */
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@StripPostfix("param")
 	void glGetVertexArrayIntegervEXT(@GLuint int vaobj, @GLenum int pname, @OutParameter @Check("16") IntBuffer param);
@@ -1482,12 +1465,10 @@ public interface EXT_direct_state_access {
 	@StripPostfix("param")
 	void glGetVertexArrayIntegervEXT2(@GLuint int vaobj, @GLenum int pname, @OutParameter IntBuffer param);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@StripPostfix("param")
 	void glGetVertexArrayPointervEXT(@GLuint int vaobj, @GLenum int pname, @Result @GLvoid ByteBuffer param);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@StripPostfix(value = "param")
 	void glGetVertexArrayIntegeri_vEXT(@GLuint int vaobj, @GLuint int index, @GLenum int pname, @OutParameter @Check("16") IntBuffer param);
@@ -1498,7 +1479,6 @@ public interface EXT_direct_state_access {
 	@StripPostfix(value = "param", postfix = "_v")
 	void glGetVertexArrayIntegeri_vEXT2(@GLuint int vaobj, @GLuint int index, @GLenum int pname, @OutParameter IntBuffer param);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@StripPostfix(value = "param")
 	void glGetVertexArrayPointeri_vEXT(@GLuint int vaobj, @GLuint int index, @GLenum int pname, @Result @GLvoid ByteBuffer param);
@@ -1522,14 +1502,12 @@ public interface EXT_direct_state_access {
 	 *
 	 * @return A ByteBuffer representing the mapped buffer memory.
 	 */
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	@CachedResult(isRange = true)
 	@GLvoid
-	@AutoResultSize("length")
+	@AutoSize("length")
 	ByteBuffer glMapNamedBufferRangeEXT(@GLuint int buffer, @GLintptr long offset, @GLsizeiptr long length, @GLbitfield int access);
 
-	@Optional(reason = "AMD does not expose this (last driver checked: 10.5)")
 	@Dependent("OpenGL30")
 	void glFlushMappedNamedBufferRangeEXT(@GLuint int buffer, @GLintptr long offset, @GLsizeiptr long length);
 
