@@ -32,6 +32,8 @@
 package org.lwjgl.opengl;
 
 import org.lwjgl.util.generator.*;
+import org.lwjgl.util.generator.Alternate;
+import org.lwjgl.util.generator.opengl.*;
 
 import java.nio.*;
 
@@ -294,7 +296,7 @@ public interface GL30 {
 	 */
 	@CachedResult(isRange = true)
 	@GLvoid
-	@AutoResultSize("length")
+	@AutoSize("length")
 	ByteBuffer glMapBufferRange(@GLenum int target, @GLintptr long offset, @GLsizeiptr long length, @GLbitfield int access);
 
 	void glFlushMappedBufferRange(@GLenum int target, @GLintptr long offset, @GLsizeiptr long length);
@@ -412,15 +414,18 @@ public interface GL30 {
 	int GL_TEXTURE_SHARED_SIZE = 0x8C3F;
 
 	// ----------------------------------------------------------------------
-	// ----------------------[ EXT_framebuffer_object ]----------------------
+	// ----------------------[ ARB_framebuffer_object ]----------------------
 	// ----------------------------------------------------------------------
 
 	/**
 	 * Accepted by the &lt;target&gt; parameter of BindFramebuffer,
-	 * CheckFramebufferStatus, FramebufferTexture{1D|2D|3D}, and
-	 * FramebufferRenderbuffer:
+	 * CheckFramebufferStatus, FramebufferTexture{1D|2D|3D},
+	 * FramebufferRenderbuffer, and
+	 * GetFramebufferAttachmentParameteriv:
 	 */
 	int GL_FRAMEBUFFER = 0x8D40;
+	int GL_READ_FRAMEBUFFER = 0x8CA8;
+	int GL_DRAW_FRAMEBUFFER = 0x8CA9;
 
 	/**
 	 * Accepted by the &lt;target&gt; parameter of BindRenderbuffer,
@@ -457,7 +462,18 @@ public interface GL30 {
 	int GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME = 0x8CD1;
 	int GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL = 0x8CD2;
 	int GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE = 0x8CD3;
-	int GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET = 0x8CD4;
+	int GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING = 0x8210;
+	int GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE = 0x8211;
+	int GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE = 0x8212;
+	int GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE = 0x8213;
+	int GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE = 0x8214;
+	int GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE = 0x8215;
+	int GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE = 0x8216;
+	int GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE = 0x8217;
+
+	/** Returned in &lt;params&gt; by GetFramebufferAttachmentParameteriv: */
+	int GL_FRAMEBUFFER_DEFAULT = 0x8218;
+	int GL_INDEX = 0x8222;
 
 	/**
 	 * Accepted by the &lt;attachment&gt; parameter of
@@ -482,19 +498,22 @@ public interface GL30 {
 	int GL_COLOR_ATTACHMENT15 = 0x8CEF;
 	int GL_DEPTH_ATTACHMENT = 0x8D00;
 	int GL_STENCIL_ATTACHMENT = 0x8D20;
+	int GL_DEPTH_STENCIL_ATTACHMENT = 0x821A;
 
 	/** Returned by CheckFramebufferStatus(): */
 	int GL_FRAMEBUFFER_COMPLETE = 0x8CD5;
 	int GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT = 0x8CD6;
 	int GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT = 0x8CD7;
-	int GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS = 0x8CD9;
-	int GL_FRAMEBUFFER_INCOMPLETE_FORMATS = 0x8CDA;
 	int GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER = 0x8CDB;
 	int GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER = 0x8CDC;
 	int GL_FRAMEBUFFER_UNSUPPORTED = 0x8CDD;
+	int GL_FRAMEBUFFER_UNDEFINED = 0x8219;
 
-	/** Accepted by GetIntegerv(): */
-	int GL_FRAMEBUFFER_BINDING = 0x8CA6;
+	/**
+	 * Accepted by the &lt;pname&gt; parameters of GetIntegerv, GetFloatv,
+	 * and GetDoublev:
+	 */
+	int GL_FRAMEBUFFER_BINDING = 0x8CA6; // alias DRAW_FRAMEBUFFER_BINDING
 	int GL_RENDERBUFFER_BINDING = 0x8CA7;
 	int GL_MAX_COLOR_ATTACHMENTS = 0x8CDF;
 	int GL_MAX_RENDERBUFFER_SIZE = 0x84E8;
@@ -509,7 +528,7 @@ public interface GL30 {
 	void glDeleteRenderbuffers(@AutoSize("renderbuffers") int n, @Const @GLuint IntBuffer renderbuffers);
 
 	@Alternate("glDeleteRenderbuffers")
-	void glDeleteRenderbuffers(@Constant("1") int n, @Constant(value = "APIUtils.getBufferInt().put(0, renderbuffer), 0", keepParam = true) int renderbuffer);
+	void glDeleteRenderbuffers(@Constant("1") int n, @Constant(value = "APIUtil.getBufferInt().put(0, renderbuffer), 0", keepParam = true) int renderbuffer);
 
 	void glGenRenderbuffers(@AutoSize("renderbuffers") int n, @OutParameter @GLuint IntBuffer renderbuffers);
 
@@ -534,7 +553,7 @@ public interface GL30 {
 	void glDeleteFramebuffers(@AutoSize("framebuffers") int n, @Const @GLuint IntBuffer framebuffers);
 
 	@Alternate("glDeleteFramebuffers")
-	void glDeleteFramebuffers(@Constant("1") int n, @Constant(value = "APIUtils.getBufferInt().put(0, framebuffer), 0", keepParam = true) int framebuffer);
+	void glDeleteFramebuffers(@Constant("1") int n, @Constant(value = "APIUtil.getBufferInt().put(0, framebuffer), 0", keepParam = true) int framebuffer);
 
 	void glGenFramebuffers(@AutoSize("framebuffers") int n, @OutParameter @GLuint IntBuffer framebuffers);
 
@@ -610,15 +629,6 @@ public interface GL30 {
 	// ----------------------[ EXT_framebuffer_blit ]----------------------
 	// --------------------------------------------------------------------
 
-	/**
-	 * Accepted by the &lt;target&gt; parameter of BindFramebuffer,
-	 * CheckFramebufferStatus, FramebufferTexture{1D|2D|3D},
-	 * FramebufferRenderbuffer, and
-	 * GetFramebufferAttachmentParameteriv.
-	 */
-	int GL_READ_FRAMEBUFFER = 0x8CA8;
-	int GL_DRAW_FRAMEBUFFER = 0x8CA9;
-
 	/** Accepted by the &lt;pname&gt; parameters of GetIntegerv, GetFloatv, and GetDoublev. */
 	int GL_DRAW_FRAMEBUFFER_BINDING = 0x8CA6; // alias FRAMEBUFFER_BINDING
 	int GL_READ_FRAMEBUFFER_BINDING = 0x8CAA;
@@ -702,14 +712,14 @@ public interface GL30 {
 
 	@Alternate("glTexParameterIiv")
 	@StripPostfix(value = "param", postfix = "v")
-	void glTexParameterIiv(@GLenum int target, @GLenum int pname, @Constant(value = "APIUtils.getBufferInt().put(0, param), 0", keepParam = true) int param);
+	void glTexParameterIiv(@GLenum int target, @GLenum int pname, @Constant(value = "APIUtil.getBufferInt().put(0, param), 0", keepParam = true) int param);
 
 	@StripPostfix("params")
 	void glTexParameterIuiv(@GLenum int target, @GLenum int pname, @Check("4") @GLuint IntBuffer params);
 
 	@Alternate("glTexParameterIuiv")
 	@StripPostfix(value = "param", postfix = "v")
-	void glTexParameterIuiv(@GLenum int target, @GLenum int pname, @Constant(value = "APIUtils.getBufferInt().put(0, param), 0", keepParam = true) int param);
+	void glTexParameterIuiv(@GLenum int target, @GLenum int pname, @Constant(value = "APIUtil.getBufferInt().put(0, param), 0", keepParam = true) int param);
 
 	@StripPostfix("params")
 	void glGetTexParameterIiv(@GLenum int target, @GLenum int pname, @OutParameter @Check("4") IntBuffer params);
@@ -969,12 +979,12 @@ public interface GL30 {
 	void glEndTransformFeedback();
 
 	void glTransformFeedbackVaryings(@GLuint int program, @GLsizei int count,
-	                                 @Const @NullTerminated("count") @GLchar @StringList("count") ByteBuffer varyings,
+	                                 @Const @NullTerminated("count") @GLchar @PointerArray("count") ByteBuffer varyings,
 	                                 @GLenum int bufferMode);
 
 	@Alternate("glTransformFeedbackVaryings")
 	void glTransformFeedbackVaryings(@GLuint int program, @Constant("varyings.length") @GLsizei int count,
-	                                 @Const @NullTerminated @StringList("count") CharSequence[] varyings,
+	                                 @Const @NullTerminated @PointerArray("count") CharSequence[] varyings,
 	                                 @GLenum int bufferMode);
 
 	void glGetTransformFeedbackVarying(@GLuint int program, @GLuint int index, @AutoSize("name") @GLsizei int bufSize,
@@ -1001,12 +1011,15 @@ public interface GL30 {
 	 */
 	int GL_VERTEX_ARRAY_BINDING = 0x85B5;
 
+	@Code("		StateTracker.bindVAO(caps, array);")
 	void glBindVertexArray(@GLuint int array);
 
+	@Code("		StateTracker.deleteVAO(caps, arrays);")
 	void glDeleteVertexArrays(@AutoSize("arrays") @GLsizei int n, @Const @GLuint IntBuffer arrays);
 
 	@Alternate("glDeleteVertexArrays")
-	void glDeleteVertexArrays(@Constant("1") @GLsizei int n, @Constant(value = "APIUtils.getBufferInt().put(0, array), 0", keepParam = true) int array);
+	@Code("		StateTracker.deleteVAO(caps, array);")
+	void glDeleteVertexArrays(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getBufferInt().put(0, array), 0", keepParam = true) int array);
 
 	void glGenVertexArrays(@AutoSize("arrays") @GLsizei int n, @OutParameter @GLuint IntBuffer arrays);
 
