@@ -32,6 +32,8 @@
 package org.lwjgl.opengl;
 
 import org.lwjgl.util.generator.*;
+import org.lwjgl.util.generator.Alternate;
+import org.lwjgl.util.generator.opengl.*;
 
 import java.nio.ByteBuffer;
 import java.nio.DoubleBuffer;
@@ -46,16 +48,12 @@ public interface GL40 {
 	// ----------------------[ ARB_draw_buffers_blend ]----------------------
 	// ----------------------------------------------------------------------
 
-	@Optional(reason = "AMD's 4.0 implementation does not expose this (last driver checked: 10.3)")
 	void glBlendEquationi(@GLuint int buf, @GLenum int mode);
 
-	@Optional(reason = "AMD's 4.0 implementation does not expose this (last driver checked: 10.3)")
 	void glBlendEquationSeparatei(@GLuint int buf, @GLenum int modeRGB, @GLenum int modeAlpha);
 
-	@Optional(reason = "AMD's 4.0 implementation does not expose this (last driver checked: 10.3)")
 	void glBlendFunci(@GLuint int buf, @GLenum int src, @GLenum int dst);
 
-	@Optional(reason = "AMD's 4.0 implementation does not expose this (last driver checked: 10.3)")
 	void glBlendFuncSeparatei(@GLuint int buf, @GLenum int srcRGB, @GLenum int dstRGB, @GLenum int srcAlpha, @GLenum int dstAlpha);
 
 	// -----------------------------------------------------------------
@@ -186,7 +184,7 @@ public interface GL40 {
 	 */
 	int GL_MIN_SAMPLE_SHADING_VALUE = 0x8C37;
 
-	@Optional(reason = "AMD's 4.0 implementation does not expose this (last driver checked: 10.3)")
+	@Optional(reason = "AMD does not expose this (last driver checked: 10.9)")
 	void glMinSampleShading(@GLclampf float value);
 
 	// ---------------------------------------------------------------------
@@ -406,7 +404,7 @@ public interface GL40 {
 	void glDeleteTransformFeedbacks(@AutoSize("ids") @GLsizei int n, @Const @GLuint IntBuffer ids);
 
 	@Alternate("glDeleteTransformFeedbacks")
-	void glDeleteTransformFeedbacks(@Constant("1") @GLsizei int n, @Constant(value = "APIUtils.getBufferInt().put(0, id), 0", keepParam = true) int id);
+	void glDeleteTransformFeedbacks(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getBufferInt().put(0, id), 0", keepParam = true) int id);
 
 	void glGenTransformFeedbacks(@AutoSize("ids") @GLsizei int n, @OutParameter @GLuint IntBuffer ids);
 
